@@ -132,10 +132,10 @@ class AutonomousExperimenterGP():
         if self.async_train: self.gp_optimizer.kill_async_train(self.opt_obj)
 
     def update_hps(self):
-        print("The autonomous experimenter is trying to update the huperparameters.")
+        print("The Autonomous Experimenter is trying to update the hyperparameters.")
         if self.async_train:
             self.gp_optimizer.update_hyperparameters(self.opt_obj)
-            print("The Autonomus Experimenter updated the Hyperparameters")
+            print("The Autonomus Experimenter updated the hyperparameters")
         else: print("The autonomous experimenter could not find an instance of asynchronous training. Therefore, no update.")
         print("hps: ", self.gp_optimizer.hyperparameters)
 
@@ -236,7 +236,7 @@ class AutonomousExperimenterGP():
             print(next_measurement_points)
             #update and tell() new data
             info  = [{"hyperparameters" : self.gp_optimizer.hyperparameters,
-                      "posterior variance" : post_var[i]} for i in range(len(next_measurement_points))]
+                      "posterior std" : np.sqrt(post_var[j])} for j in range(len(next_measurement_points))]
             new_data = self.data.inject_arrays(next_measurement_points, info = info)
             print("Sending request to instrument ...")
             if self.append: self.data.dataset = self.data.dataset + self.instrument_func(new_data)
@@ -276,6 +276,7 @@ class AutonomousExperimenterGP():
                 print("    No training in this round but I am trying to update the hyperparameters")
                 self.update_hps()
             ###save some data
+            if self.run_every_iteration is not None: self.run_every_iteration(self)
             try: np.save('Data_'+ start_date_time, self.data.dataset)
             except Exception as e: print("Data not saved due to ", str(e))
             ###########################
