@@ -74,8 +74,8 @@ class gpData:
         d["time stamp"] = time.time()
         d["date time"] = datetime.datetime.now().strftime("%d/%m/%Y_%H:%M%S")
         d["measured"] = False
-        d["posterior variance"] = None #post_var
-        d["hyperparameters"] = None #hps
+        #d["posterior variance"] = None #post_var
+        #d["hyperparameters"] = None #hps
         return d
     ###############################################################
     ###Printing####################################################
@@ -156,7 +156,7 @@ class gpData:
     def check_incoming_data(self):
         for entry in self.dataset:
             if entry["value"] is None:
-                raise Exception("Entry with no secified value entry in communicated list of data dictionaries")
+                raise Exception("Entry with no specified value entry in communicated list of data dictionaries")
 
     def clean_data_NaN(self):
         for entry in self.dataset:
@@ -256,8 +256,8 @@ class fvgpData(gpData):
         d["time stamp"] = time.time()
         d["date time"] = datetime.datetime.now().strftime("%d/%m/%Y_%H:%M%S")
         d["measured"] = False
-        d["posterior variances"] = None
-        d["hyperparameters"] = None
+        #d["posterior variances"] = None
+        #d["hyperparameters"] = None
         return d
 
     ################################################################
